==> archibald-7.x-2.0.tar.gz: archibald/templates/archibald_content_overview_row.tpl.php <==
<?php
global $language;

/**
 * @file archibald_content_overview_row.tpl.php
 * Display one row of archibald content overview resultset
 *
 * - $title: ArchibaldLom general.title as string
 * - $description: ArchibaldLom general.description as string (uncutted)
 * - $preview_image: ArchibaldLom technical.preview_image Image URL
 * - $preview_image_fid: ArchibaldLom technical.preview_image Image fid (file id)
 * - $preview_image_img: renderd and themed preview image
 * - $default_language: ArchibaldLom meta-meatadata.language Lom Object default language
 * - $status: ArchibaldLom lifecycle.status string
 * - $lom_id: ArchibaldLom id   string(32) md5 sum
 * - $version: lom version id  string(32) md5 sum
 *
 * @parent archibald_content_overview.tpl.php
 */

?>
<div class="archibald_content_overview_row_content archibald_corc_has_img">
 <?PHP
echo $preview_image_img;

if (!empty($company_logo)) {
  echo $company_logo;
}
?>
 <h3><?php echo l($title, 'archibald/' . $lom_id); ?></h3>
 <span class="description"><?php print $description; ?></span>
 <p class="info">&nbsp;</p>
 <div class="clear"></div>
</div>

 <?PHP if (!empty($childs)) { ?>
  <div class="archibald_row_childs details">
     <?PHP
$x = 0;
foreach ($childs as $child) {
  $x++;
  if ($x == 4) { ?>
    <a href ='javascript:void(0)' class='btndetails inactive' id='toggleresourceelm_<?PHP echo $lom_id ?>'><?PHP t("Show more related resources") ?></a>
    <div class='detailscontainer toggle_resource_childs' id='toggleresourcediv_<?PHP echo $lom_id ?>'>"
  <?PHP } ?>
    <div class="archibald_row_child">
  <?PHP print $child->preview_image; ?>
    <h4><?php echo l($child->title, 'archibald/' . $child->lom_id); ?></h4>
    <span class="description"><?php print $child->description; ?></span>
      <p class="info">&nbsp;</p>
      <div class="clear"></div>
    </div>
    <?PHP } if ($x > 3) { ?></div><?php } ?>
  </div>
 <?PHP }

==> archibald-7.x-2.1.tar.gz: archibald/templates/archibald_content_overview_row.tpl.php <==
<?php
global $language;

/**
 * @file
 * archibald_content_overview_row.tpl.php
 * Display one row of archibald content overview resultset
 *
 * - $title: ArchibaldLom general.title as string
 * - $description: ArchibaldLom general.description as string (uncutted)
 * - $preview_image: ArchibaldLom technical.preview_image Image URL
 * - $preview_image_fid: ArchibaldLom technical.preview_image Image fid (file id)
 * - $preview_image_img: renderd and themed preview image
 * - $default_language: ArchibaldLom meta-meatadata.language Lom Object default language
 * - $status: ArchibaldLom lifecycle.status string
 * - $lom_id: ArchibaldLom id   string(32) md5 sum
 * - $version: lom version id  string(32) md5 sum
 *
 * @parent archibald_content_overview.tpl.php
 */

?>
<div class="archibald_content_overview_row_content archibald_corc_has_img">
 <?PHP
echo $preview_image_img;

if (!empty($company_logo)) {
  echo $company_logo;
}
?>
 <h3><?php echo l($title, 'archibald/' . $lom_id); ?></h3>
 <span class="description"><?php print $description; ?></span>
 <p class="info">&nbsp;</p>
 <div class="clear"></div>
</div>

 <?PHP if (!empty($childs)) { ?>
  <div class="archibald_row_childs details">
     <?PHP
$x = 0;
foreach ($childs as $child) {
  $x++;
  if ($x == 4) { ?>
    <a href ='javascript:void(0)' class='btndetails inactive' id='toggleresourceelm_<?PHP echo $lom_id ?>'><?PHP t('Show more related descriptions') ?></a>
    <div class='detailscontainer toggle_resource_childs' id='toggleresourcediv_<?PHP echo $lom_id ?>'>"
  <?PHP } ?>
    <div class="archibald_row_child">
  <?PHP print $child->preview_image; ?>
    <h4><?php echo l($child->title, 'archibald/' . $child->lom_id); ?></h4>
    <span class="description"><?php print $child->description; ?></span>
      <p class="info">&nbsp;</p>
      <div class="clear"></div>
    </div>
    <?PHP } if ($x > 3) { ?></div><?php } ?>
  </div>
 <?PHP }
